// $Id: exerb.h,v 1.17 2003/02/21 05:30:13 yuya Exp $

////////////////////////////////////////////////////////////////////////////////

#pragma warning(disable : 4786)

////////////////////////////////////////////////////////////////////////////////

#include <windows.h>
#include <windowsx.h>
#include <vector>
#include <map>
#include <string>
#include <sys/stat.h>

#include "ruby.h"

#ifdef NT
#include "win32/win32.h"
#endif

#include "pe.h"
#include "exerbmod.h"
#include "def.h"
#include "resource.h"

#ifdef USE_ZLIB
#include "zlib.h"
#endif

#ifdef USE_BRUBY
#include "BRb.h"
#endif

////////////////////////////////////////////////////////////////////////////////

#ifdef _DEBUG
#define DEBUGMSG0(msg)          ::fprintf(stderr, "[Exerb] " msg)
#define DEBUGMSG1(msg, p1)      ::fprintf(stderr, "[Exerb] " msg, p1)
#define DEBUGMSG2(msg, p1, p2)  ::fprintf(stderr, "[Exerb] " msg, p1, p2)
#else
#define DEBUGMSG0(msg)
#define DEBUGMSG1(msg, p1)
#define DEBUGMSG2(msg, p1, p2)
#endif

////////////////////////////////////////////////////////////////////////////////

using namespace std;

////////////////////////////////////////////////////////////////////////////////

typedef void (*ON_ERROR_FNC)(LPSTR);
typedef void (*ON_FAIL_FNC)(VALUE);

////////////////////////////////////////////////////////////////////////////////

int  ExMain(int argc, char **argv, ON_ERROR_FNC onerror, ON_FAIL_FNC onfail);
void ExGetSelfFilePath(LPSTR filepath_buffer, UINT size);
void ExGetSelfFileName(LPSTR filename_buffer, UINT size);
void ExRaiseException(VALUE klass, int res_id);
void ExRaiseExceptionVar(VALUE klass, int res_id, ...);

////////////////////////////////////////////////////////////////////////////////
